From 3f28d1099ed68ac5e2682e7a7198b4034f4d3268 Mon Sep 17 00:00:00 2001
From: Sean McGovern <gseanmcg@gmail.com>
Date: Sun, 10 Oct 2010 19:34:18 -0400
Subject: [PATCH] Fix build on SPARC Solaris 10

---
 Makefile       |    2 +-
 common/pixel.c |    6 +++---
 configure      |   27 ++++++++++++++++-----------
 3 files changed, 20 insertions(+), 15 deletions(-)

diff --git a/Makefile b/Makefile
index ebf1f62..972fff0 100644
--- a/Makefile
+++ b/Makefile
@@ -104,7 +104,7 @@ endif
 endif
 
 # VIS optims
-ifeq ($(ARCH),UltraSparc)
+ifeq ($(ARCH),UltraSPARC)
 ASMSRC += common/sparc/pixel.asm
 OBJASM  = $(ASMSRC:%.asm=%.o)
 endif
diff --git a/common/pixel.c b/common/pixel.c
index a19725f..3461535 100644
--- a/common/pixel.c
+++ b/common/pixel.c
@@ -36,7 +36,7 @@
 #if ARCH_ARM
 #   include "arm/pixel.h"
 #endif
-#if ARCH_UltraSparc
+#if ARCH_UltraSPARC
 #   include "sparc/pixel.h"
 #endif
 
@@ -436,7 +436,7 @@ SAD_X( 4x8 )
 SAD_X( 4x4 )
 
 #if !X264_HIGH_BIT_DEPTH
-#if ARCH_UltraSparc
+#if ARCH_UltraSPARC
 SAD_X( 16x16_vis )
 SAD_X( 16x8_vis )
 SAD_X( 8x16_vis )
@@ -948,7 +948,7 @@ void x264_pixel_init( int cpu, x264_pixel_function_t *pixf )
     }
 #endif
 #if !X264_HIGH_BIT_DEPTH
-#if ARCH_UltraSparc
+#if ARCH_UltraSPARC
     INIT4( sad, _vis );
     INIT4( sad_x3, _vis );
     INIT4( sad_x4, _vis );
diff --git a/configure b/configure
index 1ad2b57..eb374fa 100755
--- a/configure
+++ b/configure
@@ -380,15 +380,20 @@ case $host_cpu in
     fi
     ;;
   sparc)
-    if [ $asm = auto ] && test "$(uname -m)" = "sun4u"; then
-      ARCH="UltraSparc"
-      CFLAGS="$CFLAGS -mcpu=ultrasparc"
-      LDFLAGS="$LDFLAGS -mcpu=ultrasparc"
-      AS="${AS-${cross_prefix}as}"
-      ASFLAGS="$ASFLAGS -xarch=v8plusa"
-    else
-      ARCH="Sparc"
-    fi
+    ARCH="SPARC"
+    case $(uname -m) in
+      sun4u|sun4v)
+        if [ $asm = auto ]; then
+          ARCH="UltraSPARC"
+          if ! echo $CFLAGS | grep -Eq '\-mcpu' ; then
+            CFLAGS="$CFLAGS -mcpu=ultrasparc"
+            LDFLAGS="$LDFLAGS -mcpu=ultrasparc"
+          fi
+          AS="${AS-${cross_prefix}as}"
+          ASFLAGS="$ASFLAGS -xarch=v8plusa"
+        fi
+        ;;
+    esac
     ;;
   mips|mipsel|mips64|mips64el)
     ARCH="MIPS"
@@ -487,9 +492,9 @@ define SYS_$SYS
 
 echo "int i = 0x42494745; double f = 0x1.0656e6469616ep+102;" > conftest.c
 $CC $CFLAGS conftest.c -c -o conftest.o 2>$DEVNULL || die "endian test failed"
-if grep -q BIGE conftest.o && grep -q FPendian conftest.o ; then
+if (strings -a conftest.o | grep -q BIGE) && (strings -a conftest.o | grep -q FPendian) ; then
     define WORDS_BIGENDIAN
-elif !(grep -q EGIB conftest.o && grep -q naidnePF conftest.o) ; then
+elif !(strings -a conftest.o | grep -q EGIB && strings -a conftest.o | grep -q naidnePF) ; then
     die "endian test failed"
 fi
 
-- 
1.7.2
